@@ -1,5 +1,5 @@
 package Dancer2::Template::Implementation::ForkedTiny;
-$Dancer2::Template::Implementation::ForkedTiny::VERSION = '0.149000_01';
+$Dancer2::Template::Implementation::ForkedTiny::VERSION = '0.149000_02';
 # ABSTRACT: Dancer2 own implementation of Template::Tiny
 
 use 5.00503;
@@ -190,7 +190,7 @@ sub _expression {
     foreach (@path) {
 
         # Support for private keys
-        return undef if substr( $_, 0, 1 ) eq '_';
+        return if substr( $_, 0, 1 ) eq '_';
 
         # Split by data type
         my $type = ref $cursor;
@@ -227,7 +227,7 @@ Dancer2::Template::Implementation::ForkedTiny - Dancer2 own implementation of Te
 
 =head1 VERSION
 
-version 0.149000_01
+version 0.149000_02
 
 =head1 SYNOPSIS
 
